==> babel-build-1.0.1.tgz: package/lib/clean.js <==
'use strict';

var _del = require('del');

var _del2 = _interopRequireDefault(_del);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; } /**
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            * Created by Zhengfeng.Yao on 16/9/22.
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            */


module.exports = function () {
  var _ref = _asyncToGenerator(regeneratorRuntime.mark(function _callee(dirs) {
    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.next = 2;
            return (0, _del2.default)(dirs, { dot: true });

          case 2:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, this);
  }));

  function clean(_x) {
    return _ref.apply(this, arguments);
  }

  return clean;
}();

==> babel-build-1.0.2.tgz: package/lib/clean.js <==
'use strict';

var _del = require('del');

var _del2 = _interopRequireDefault(_del);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; } /**
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            * Created by Zhengfeng.Yao on 16/9/22.
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            */


module.exports = function () {
  var _ref = _asyncToGenerator(regeneratorRuntime.mark(function _callee(dirs, force) {
    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.next = 2;
            return (0, _del2.default)(dirs, { force: !!force });

          case 2:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, this);
  }));

  function clean(_x, _x2) {
    return _ref.apply(this, arguments);
  }

  return clean;
}();
